This function facilitates construction of a complete style set based on the
classic look of an HTML rendered markdown document. It contains style
specifications for all the supported markdown elements as well as a sub and
sup style that can be used for subscripts and superscript respectively.
These are only accessible through custom spans (e.g. H{.sub 2}O) as
markdown doesn't provide a syntax for these formats.
classic_style(
base_size = 12,
body_font = "",
header_font = "",
code_font = "mono",
...,
ltr = TRUE
)A style set object
The base font size for the text. All other sizing is based on this
The font family to use for body text
The font family to use for headers
The font family to use for code and code block text
Arguments passed on to base_style
weightThe font weight to use. Can either be a number (0, 100,
200, 300, 400, 500, 600, 700, 800, or 900) or a strings
("undefined", "thin", "ultralight", "light", "normal", "medium",
"semibold", "bold", "ultrabold", or "heavy")
italicShould the font be slanted
widthThe font width to use. Can either be a number (``0, 1`, `2`,
`3`, `4`, `5`, `6`, `7`, `8`, or `9`) or strings (`"undefined"`,
`"ultracondensed"`, `"extracondensed"`, `"condensed"`, `"semicondensed"`,
`"normal"`, `"semiexpanded"`, `"expanded"`, `"extraexpanded"`, or
`"ultraexpanded"`)
featuresA font_feature object specifying any OpenType font features to apply to the font
colorIs the color of the font
lineheightThe spacing between subsequent lines relative to the font
size. Can be relative() in which case it is based on the parent lineheight.
alignThe alignment within the text. One of "left", "center",
"right", "justified-left", "justified-center", "justified-right", or
"distributed"
trackingAdditional character spacing measured in 1/1000em. Can be
relative() in which case it is based on the parent tracking.
indentThe indentation of the first line in a paragraph measured in
points. Can be relative() in which case it is based on the parent indent,
em() in which case it is based on the font size in this style, or rem()
in which case it is based on the font size of the body element.
hangingThe indentation of all but the first line in a paragraph
measured in points. Can be relative() in which case it is based on the
parent hanging, em() in which case it is based on the font size in this
style, or rem() in which case it is based on the font size of the body
element.
marginThe margin around the element, given as a call to trbl().
Margin refers to the area outside the box that text is placed in. If the
element has a background, the margin area will not be colored.
paddingThe padding around the element, given as a call to trbl().
Padding refers to the distance between the text and the border of the box it
will be drawn in. If the element has a background, the padding area will be
colored.
backgroundThe color of the background fill. The background includes
the padding but not the margin. Can be a solid color or a gradient or pattern
made with grid::linearGradient()/grid::radialGradient()/grid::pattern()
borderThe color of the background stroke. The background includes the padding but not the margin
border_sizeThe line width of the background stroke, given as a call
to trbl()
border_radiusThe corner radius of the background, given in points
outlineThe color of the outline stroke.
outline_widthThe line width of the outline stroke.
outline_joinThe line join type for the outline. Either "round",
"mitre", or "bevel".
outline_mitreThe mitre limit (relative distance between inner and
outer corner at a join) if outline_join = "mitre".
bulletsA vector of strings to use for bullets in unordered lists.
marquee_bullets provides a selection
underlineShould text be underlined
strikethroughShould text be strikethrough
baselineThe baseline shift to apply to the text
img_aspThe default aspect ratio for block level images if not provided by the image itself
text_directionThe directional flow of the text. Either "auto" to
let it be determined by the content of the text, or "ltr"/"rtl" to
hard-code it to either left-to-right or right-to-left. This setting will not
change the order of glyphs within a span of text, but rather whether
consequtive blocks of text are laid out left-to-right or right-to-left. It
also affects to which side indentation is applied as well as the meaning of
"auto", and "justified-auto" aligment.
Is the style intended for left-to-right text? This affects list indentation and citation border
classic_style(16, "serif", "sans")
Run the code above in your browser using DataLab